<!--
SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>

SPDX-License-Identifier: CC-BY-SA-4.0
-->

[![Open Web Calendar](https://open-web-calendar.quelltext.eu/assets/img/logo/github-social-preview.svg)][web]

[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/niccokunzmann/open-web-calendar/run-tests.yml?logo=github)](https://github.com/niccokunzmann/open-web-calendar/actions)
![](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)

You might want to:
- **[Try&nbsp;it&nbsp;out][web]**
- [Contribute!](https://open-web-calendar.quelltext.eu/contributing/)
- [Read the documentation][docs]


Python: 3.9, 3.10, 3.11, 3.12

There are several commercial solutions which allow embedding of calendars into my website.
I only have a link to an ICS file and want to show a nice-looking calendar on my site.
Browser-only calendars usually have the problem that many ICS files can not be
accessed (such as ownCloud/nextCloud in my case).
I also want to be in control over who knows the people who
visit the site and not pass everything to Google.
This is a solution in my case which I share with the world.
You are free to use it or deploy your own, modify or share it.
It works offline and in company networks, too.

Features
- Embedded calendar
- Choice of time zone
- ICS link, best multiple
- month/week as a view
- name, time of event, link?
- showing the time span
- styling of choice (icon, color, font, ...)



[web]: https://open-web-calendar.hosted.quelltext.eu/
[docs]: https://open-web-calendar.quelltext.eu/

Changelog
---------

The changelog can be found [here](https://open-web-calendar.quelltext.eu/changelog/).

Funding
-------

[<img alt="Logo NLnet: abstract logo of four people seen from above" src="https://nlnet.nl/logo/banner.svg" height="50px" />](https://nlnet.nl/) [<img alt="Logo NGI Zero: letterlogo shaped like a tag" src="https://nlnet.nl/image/logos/NGI0Core_tag.svg" height="50px" />](https://nlnet.nl/core)

This project was funded in 2024 through the [NGI0 Core Fund](https://nlnet.nl/core), a fund established by [NLnet](https://nlnet.nl/) with financial support from the European Commission's [Next Generation Internet programme](https://ngi.eu/). You might be able to get funded, too!
